Role

Enum Role 

pub enum Role {
Show 41 variants Window, Region, Group, List, Row, Button, Link, Tab, TabPanel, Input, MultilineInput, PasswordInput, Text, Heading, Dialog, Menu, MenuItem, Status, Checkbox, Radio, Switch, Slider, Table, TreeGrid, Cell, GridCell, Tree, TreeItem, Progress, Toast, Tooltip, Separator, Splitter, Toolbar, Scrollbar, Combobox, Option, Form, Field, Image, Drag,
}

Variants



Window



Region



Group



List



Row



Button



Tab



TabPanel



Input



MultilineInput



PasswordInput



Text



Heading



Dialog



Menu



MenuItem



Status



Checkbox



Radio



Switch



Slider



Table



TreeGrid



Cell



GridCell



Tree



TreeItem



Progress



Toast



Tooltip



Separator



Splitter



Toolbar



Scrollbar



Combobox



Option



Form



Field



Image



Drag

A drag in flight: what is being carried, and where it would land.